@@ -1,4 +1,4 @@
-from typing import List, Any, Union
+from typing import List, Any, Union, Optional
 
 import numpy as np
 import numpy.typing as npt
@@ -34,6 +34,10 @@ class LeapImage:
     Attributes:
     data (npt.NDArray[np.float32] | npt.NDArray[np.uint8]): The image data.
     type (LeapDataType): The data type, default is LeapDataType.Image.
+
+    Example:
+        image_data = np.random.rand(100, 100, 3).astype(np.float32)
+        leap_image = LeapImage(data=image_data)
     """
     data: Union[npt.NDArray[np.float32], npt.NDArray[np.uint8]]
     type: LeapDataType = LeapDataType.Image
@@ -55,6 +59,11 @@ class LeapImageWithBBox:
     data (npt.NDArray[np.float32] | npt.NDArray[np.uint8]): The image data, shaped [H, W, 3] or [H, W, 1].
     bounding_boxes (List[BoundingBox]): List of Tensorleap bounding boxes objects in relative size to image size.
     type (LeapDataType): The data type, default is LeapDataType.ImageWithBBox.
+
+    Example:
+        image_data = np.random.rand(100, 100, 3).astype(np.float32)
+        bbox = BoundingBox(x=0.5, y=0.5, width=0.2, height=0.2, confidence=0.9, label="object")
+        leap_image_with_bbox = LeapImageWithBBox(data=image_data, bounding_boxes=[bbox])
     """
     data: Union[npt.NDArray[np.float32], npt.NDArray[np.uint8]]
     bounding_boxes: List[BoundingBox]
@@ -76,6 +85,10 @@ class LeapGraph:
     Attributes:
     data (npt.NDArray[np.float32]): The array data, shaped [M, N] where M is the number of data points and N is the number of variables.
     type (LeapDataType): The data type, default is LeapDataType.Graph.
+
+    Example:
+        graph_data = np.random.rand(100, 3).astype(np.float32)
+        leap_graph = LeapGraph(data=graph_data)
     """
     data: npt.NDArray[np.float32]
     type: LeapDataType = LeapDataType.Graph
@@ -96,9 +109,15 @@ class LeapText:
     data (List[str]): The text data, consisting of a list of text tokens. If the model requires fixed-length inputs,
     it is recommended to maintain the fixed length, using empty strings ('') instead of padding tokens ('PAD') e.g., ['I', 'ate', 'a', 'banana', '', '', '', ...]
     type (LeapDataType): The data type, default is LeapDataType.Text.
+
+    Example:
+        text_data = ['I', 'ate', 'a', 'banana', '', '', '']
+        heatmap = [0.1, 0.3, 0.2, 0.9, 0.0, 0.0, 0.0]
+        leap_text = LeapText(data=text_data heatmap=heatmap)  # Create LeapText object
     """
     data: List[str]
     type: LeapDataType = LeapDataType.Text
+    heatmap: Optional[List[float]] = None
 
     def __post_init__(self) -> None:
         validate_type(self.type, LeapDataType.Text)
@@ -106,6 +125,15 @@ class LeapText:
         for value in self.data:
             validate_type(type(value), str)
 
+        if self.heatmap is not None:
+            validate_type(type(self.heatmap), list)
+            for value in self.heatmap:
+                validate_type(type(value), float)
+            if len(self.heatmap) != len(self.data):
+                raise LeapValidationError(
+                    f"Heatmap length ({len(self.heatmap)}) must match the number of tokens in `data` ({len(self.data)})."
+                )
+
 
 @dataclass
 class LeapHorizontalBar:
@@ -118,6 +146,11 @@ class LeapHorizontalBar:
     labels (List[str]): Labels for the horizontal bar; e.g., when visualizing the model's classification output, labels are the class names.
     Length of `body` should match the length of `labels`, C.
     type (LeapDataType): The data type, default is LeapDataType.HorizontalBar.
+
+    Example:
+        body_data = np.random.rand(5).astype(np.float32)
+        labels = ['Class A', 'Class B', 'Class C', 'Class D', 'Class E']
+        leap_horizontal_bar = LeapHorizontalBar(body=body_data, labels=labels)
     """
     body: npt.NDArray[np.float32]
     labels: List[str]
@@ -145,6 +178,12 @@ class LeapImageMask:
     image (npt.NDArray[np.float32] | npt.NDArray[np.uint8]): The image data, shaped [H, W, 3] or shaped [H, W, 1].
     labels (List[str]): Labels associated with the mask regions; e.g., class names for segmented objects. The length of `labels` should match the number of unique values in `mask`.
     type (LeapDataType): The data type, default is LeapDataType.ImageMask.
+
+    Example:
+        image_data = np.random.rand(100, 100, 3).astype(np.float32)
+        mask_data = np.random.randint(0, 2, (100, 100)).astype(np.uint8)
+        labels = ["background", "object"]
+        leap_image_mask = LeapImageMask(image=image_data, mask=mask_data, labels=labels)
     """
     mask: npt.NDArray[np.uint8]
     image: Union[npt.NDArray[np.float32], npt.NDArray[np.uint8]]
@@ -176,6 +215,13 @@ class LeapTextMask:
     text (List[str]): The text data, consisting of a list of text tokens, length of L.
     labels (List[str]): Labels associated with the masked tokens; e.g., named entities or sentiment categories. The length of `labels` should match the number of unique values in `mask`.
     type (LeapDataType): The data type, default is LeapDataType.TextMask.
+
+    Example:
+        text_data = ['I', 'ate', 'a', 'banana', '', '', '']
+        mask_data = np.array([0, 0, 0, 1, 0, 0, 0]).astype(np.uint8)
+        labels = ["object"]
+        leap_text_mask = LeapTextMask(text=text_data, mask=mask_data, labels=labels)
+        leap_text_mask.plot_visualizer()
     """
     mask: npt.NDArray[np.uint8]
     text: List[str]
@@ -206,6 +252,12 @@ class LeapImageWithHeatmap:
     heatmaps (npt.NDArray[np.float32]): The heatmap data, shaped [N, H, W], where N is the number of heatmaps.
     labels (List[str]): Labels associated with the heatmaps; e.g., feature names or attention regions. The length of `labels` should match the number of heatmaps, N.
     type (LeapDataType): The data type, default is LeapDataType.ImageWithHeatmap.
+
+    Example:
+        image_data = np.random.rand(100, 100, 3).astype(np.float32)
+        heatmaps = np.random.rand(3, 100, 100).astype(np.float32)
+        labels = ["heatmap1", "heatmap2", "heatmap3"]
+        leap_image_with_heatmap = LeapImageWithHeatmap(image=image_data, heatmaps=heatmaps, labels=labels)
     """
     image: npt.NDArray[np.float32]
     heatmaps: npt.NDArray[np.float32]
